==> tecfy_core_package-1.1.19.tar.gz: lib/views/entity/entity_history.pade.dart <==
part of tecfy_core_client_package;

class EntityHistoryPage extends StatefulWidget {
  final String entity;
  final String id;
  final Map<String, dynamic>? data;

  EntityHistoryPage(
    this.entity,
    this.id, {
    this.data,
    Key? key,
  }) : super(key: key);
  @override
  _EntityHistoryPageState createState() => _EntityHistoryPageState();
}

class _EntityHistoryPageState extends AppState<EntityHistoryPage> {
  List<Map<String, dynamic>>? _data;
  List<Map<String, dynamic>>? _users;
  bool _isMobile = false;

  @override
  void initState() {
    super.initState();

    TecfyBasicApp.apiService
        .httpGetDynamic(
            'EntityLog/GetLogs?entity=${widget.entity}&id=${widget.id}&actions=Add,Update,Delete')
        .then((result) {
      _data = result.data
          .map<Map<String, dynamic>>((e) => e as Map<String, dynamic>)
          .toList();
      updateUser();
      setState(() {});
    });
    EntityService.getDataEx('TecfyUser', activeOnly: false).then((result) {
      _users = result.data;
      updateUser();
      setState(() {});
    });
  }

  void updateUser() {
    if (_data == null || _users == null) return;
    for (var d in _data!) {
      if (d['userFullName'] == null && d['userId'] != null) {
        d['userFullName'] =
            _users?.firstWhere((u) => u['id'] == d['userId'])?['fullName'];
      }
    }
  }

  @override
  Widget build(BuildContext context) {
    _isMobile = LayoutService.isMobile(context);
    return BasePage(
      context,
      trans('History'),
      widget.entity,
      isMobile: _isMobile,
      child: Container(
          padding: EdgeInsets.symmetric(horizontal: 20),
          constraints: BoxConstraints(maxWidth: ThemeService.containerWidth),
          child: Column(
            children: [
              _getKeyValue('createdUserId', 'user', 'انشاء عن طريق'),
              _getKeyValue('createdTime', 'dateTime', 'وقت الانشاء'),
              _getKeyValue('updatedUserId', 'user', 'تعديل عن طريق'),
              _getKeyValue('updatedTime', 'dateTime', 'اخر تعديل'),
              _getKeyValue('timeStamp', 'dateTime', 'وقت اخر حفظ'),
              _data == null
                  ? Center(child: AppNavigator.getLoadingWidget(70))
                  : _getTable(),
            ],
          )),
    );
  }

  Widget _getKeyValue(String key, String? dataType, String? label) {
    try {
      String? value;
      if (widget.data == null || widget.data![key] == null) return SizedBox();
      switch (dataType) {
        case "dateTime":
          value = intl.DateFormat("dd/MM/yyyy HH:mm").format(
              BaseModel.getDateEx(widget.data![key])?.toLocal() ?? DateTime(0));
          break;
        case "user":
          if (_users != null &&
              widget.data![key.substring(0, key.length - 2)] == null) {
            widget.data![key.substring(0, key.length - 2)] =
                _users?.firstWhere((u) => u['id'] == widget.data![key]);
          }

          value = widget.data![key.substring(0, key.length - 2)]?['fullName'] ??
              widget.data![key];
          break;
      }
      return ConstrainedBox(
          constraints: BoxConstraints(maxWidth: 400),
          child: Row(
            children: [
              Expanded(child: Text(label ?? key), flex: 3),
              Text(' : '),
              Expanded(child: Text(value ?? '-'), flex: 6)
            ],
          ));
    } catch (err) {
      return SizedBox();
    }
  }

  Widget _getTable() {
    return AppDataTable(
      padding: EdgeInsets.only(top: 20),
      onCellClicked: (data, filed) {
        if (filed == 'action') {
          AppNavigator.showAppDialogEx(
              context,
              () => EntityFormPage(
                    widget.entity,
                    data: jsonDecode(data['model']),
                    isPopup: true,
                    readOnly: true,
                    loadData: false,
                  ),
              closeButton: true,
              size: DialogBoxSizes.large);
        }
        if (filed == 'success') {
          AppNavigator.showMessage(context, 'Result is:', MessageType.none,
              message: data['result'].toString());
        }
        if (filed == 'deviceType') {
          AppNavigator.showMessage(context, 'IP Address is:', MessageType.none,
              message: data['ipAddress'].toString());
        }
        if (filed == 'timestamp') {
          AppNavigator.showMessage(
              context,
              'Response within ${data['millisecond']} millisecond',
              MessageType.none);
        }
      },
      //isSelectedField: 'selected',
      readOnly: true,
      columns: [
        PropertyText(
            dbName: 'action',
            nameAr: 'الحدث',
            nameEn: 'Action',
            readOnly: true),
        PropertyText(
            dbName: 'userFullName',
            nameAr: 'المستخم',
            nameEn: 'User',
            readOnly: true),
        PropertyDate(
            dbName: 'timestamp',
            nameAr: 'التاريخ',
            nameEn: 'Date',
            format: 'yyyy-MM-dd    HH:mm',
            readOnly: true),
        PropertyText(
            dbName: 'clientVersion',
            nameAr: 'الاصدار',
            nameEn: 'Version',
            readOnly: true),
        PropertyText(
            dbName: 'deviceType',
            nameAr: 'الجهاز',
            nameEn: 'Device',
            readOnly: true),
        PropertyBoolean(
            dbName: 'success',
            nameAr: 'بنجاح',
            nameEn: 'Success',
            readOnly: true),
      ],
      data: _data!,
    );
  }
}

==> tecfy_core_package-1.1.25.tar.gz: lib/views/entity/entity_history.pade.dart <==
part of tecfy_core_client_package;

class EntityHistoryPage extends StatefulWidget {
  final String entity;
  final String id;
  final Map<String, dynamic>? data;

  EntityHistoryPage(
    this.entity,
    this.id, {
    this.data,
    Key? key,
  }) : super(key: key);
  @override
  _EntityHistoryPageState createState() => _EntityHistoryPageState();
}

class _EntityHistoryPageState extends AppState<EntityHistoryPage> {
  List<Map<String, dynamic>>? _data;
  List<Map<String, dynamic>>? _users;
  bool _isMobile = false;

  @override
  void initState() {
    super.initState();

    TecfyBasicApp.apiService
        .httpGetDynamic(
            'EntityLog/GetLogs?entity=${widget.entity}&id=${widget.id}&actions=Add,Update,Delete')
        .then((result) {
      _data = result.data
          .map<Map<String, dynamic>>((e) => e as Map<String, dynamic>)
          .toList();
      updateUser();
      setState(() {});
    });
    EntityService.getDataEx('TecfyUser', activeOnly: false).then((result) {
      _users = result.data;
      updateUser();
      setState(() {});
    });
  }

  void updateUser() {
    if (_data == null || _users == null) return;
    for (var d in _data!) {
      if (d['userFullName'] == null && d['userId'] != null) {
        d['userFullName'] =
            _users?.firstWhere((u) => u['id'] == d['userId'])?['fullName'];
      }
    }
  }

  @override
  Widget build(BuildContext context) {
    _isMobile = LayoutService.isMobile(context);
    return BasePage(
      context,
      trans('History'),
      widget.entity,
      isMobile: _isMobile,
      child: Container(
          padding: EdgeInsets.symmetric(horizontal: 20),
          constraints: BoxConstraints(maxWidth: ThemeService.containerWidth),
          child: Column(
            children: [
              _getKeyValue('createdUserId', 'user', 'انشاء عن طريق'),
              _getKeyValue('createdTime', 'dateTime', 'وقت الانشاء'),
              _getKeyValue('updatedUserId', 'user', 'تعديل عن طريق'),
              _getKeyValue('updatedTime', 'dateTime', 'اخر تعديل'),
              _getKeyValue('timeStamp', 'dateTime', 'وقت اخر حفظ'),
              _data == null
                  ? Center(child: AppNavigator.getLoadingWidget(70))
                  : _getTable(),
            ],
          )),
    );
  }

  Widget _getKeyValue(String key, String? dataType, String? label) {
    try {
      String? value;
      if (widget.data == null || widget.data![key] == null) return SizedBox();
      switch (dataType) {
        case "dateTime":
          value = intl.DateFormat("dd/MM/yyyy HH:mm").format(
              BaseModel.getDateEx(widget.data![key])?.toLocal() ?? DateTime(0));
          break;
        case "user":
          if (_users != null &&
              widget.data![key.substring(0, key.length - 2)] == null) {
            widget.data![key.substring(0, key.length - 2)] =
                _users?.firstWhere((u) => u['id'] == widget.data![key]);
          }

          value = widget.data![key.substring(0, key.length - 2)]?['fullName'] ??
              widget.data![key];
          break;
      }
      return ConstrainedBox(
          constraints: BoxConstraints(maxWidth: 400),
          child: Row(
            children: [
              Expanded(child: TecfyText(label ?? key), flex: 3),
              TecfyText(' : '),
              Expanded(child: TecfyText(value ?? '-'), flex: 6)
            ],
          ));
    } catch (err) {
      return SizedBox();
    }
  }

  Widget _getTable() {
    return AppDataTable(
      padding: EdgeInsets.only(top: 20),
      onCellClicked: (data, filed) {
        if (filed == 'action') {
          AppNavigator.showAppDialogEx(
              context,
              () => EntityFormPage(
                    widget.entity,
                    data: jsonDecode(data['model']),
                    isPopup: true,
                    readOnly: true,
                    loadData: false,
                  ),
              closeButton: true,
              size: DialogBoxSizes.large);
        }
        if (filed == 'success') {
          AppNavigator.showMessage(context, 'Result is:', MessageType.none,
              message: data['result'].toString());
        }
        if (filed == 'deviceType') {
          AppNavigator.showMessage(context, 'IP Address is:', MessageType.none,
              message: data['ipAddress'].toString());
        }
        if (filed == 'timestamp') {
          AppNavigator.showMessage(
              context,
              'Response within ${data['millisecond']} millisecond',
              MessageType.none);
        }
      },
      //isSelectedField: 'selected',
      readOnly: true,
      columns: [
        PropertyText(
            dbName: 'action',
            nameAr: 'الحدث',
            nameEn: 'Action',
            readOnly: true),
        PropertyText(
            dbName: 'userFullName',
            nameAr: 'المستخم',
            nameEn: 'User',
            readOnly: true),
        PropertyDate(
            dbName: 'timestamp',
            nameAr: 'التاريخ',
            nameEn: 'Date',
            format: 'yyyy-MM-dd    HH:mm',
            readOnly: true),
        PropertyText(
            dbName: 'clientVersion',
            nameAr: 'الاصدار',
            nameEn: 'Version',
            readOnly: true),
        PropertyText(
            dbName: 'deviceType',
            nameAr: 'الجهاز',
            nameEn: 'Device',
            readOnly: true),
        PropertyBoolean(
            dbName: 'success',
            nameAr: 'بنجاح',
            nameEn: 'Success',
            readOnly: true),
      ],
      data: _data!,
    );
  }
}
